/**
 * @class Sb.Application
 * @singleton
 */
Sb.Application = Ext.extend(Ext.util.Observable, {
	/**
	 * Last time when session was updated
	 */
	renewSessionHandlerLastPolling: null,

	/**
	 * Do we renew external application`s (usually a Panel) session?
	 */
	isExternalSessionRenewed: false,

	constructor: function(config) {
		this.renewSessionHandlerLastPolling = new Date().getTime();
		config = config || {};
		Ext.apply(this, config);
		this.addEvents(
			/**
			 * @event renewsession
			 * Fires when the need application session prolongation
			 */
			'renewsession'
		);
		Sb.Application.superclass.constructor.call(this, config);
		Ext.getBody().on('mousemove', this.renewSessionHandler, this);
	},

	/**
	 * Renew SiteBuilder and Control Panel sessions
	 */
	renewSessionHandler: function () {
		var now = new Date().getTime();
		if (now - this.renewSessionHandlerLastPolling > Sb.Config.renewSessionPeriod) {
			this.renewSessionHandlerLastPolling = now;
			Sb.SystemService.renewSession();
			if (this.isExternalSessionRenewed) {
				this.fireEvent('renewsession');
			}
		}
	}
});
