/**
 * @class Sb.StyleManager
 * Utility class for manipulating SiteBuilder's CSS styles
 * @singleton
 */
Sb.StyleManager = function() {
	var cache = {};
	var tasks = {};
	var	buffer = 250; // ms
		
	// Combines the styles of one section, and inserts them into the DOM
	function combineAndAdd(id) {
		var css = '';
		Ext.iterate(cache[id], function(subId, cssText) {
			css += cssText;
		});

		id = 'sb-style-' + id;
		Ext.util.CSS.removeStyleSheet(id);
		Ext.util.CSS.createStyleSheet(css, id);
	}

	return {
		addStyleSheet: function(cssText, id, subId) {
			subId = subId || id;
			if (!cache[id]) {
				cache[id] = {};
			}
			cache[id][subId] = cssText;

			if (buffer > 0) {
				if (!tasks[id]) {
					tasks[id] = new Ext.util.DelayedTask(function() {
						combineAndAdd(id);
						delete tasks[id];
					});
					tasks[id].delay(buffer);
				}
			} else {
				combineAndAdd(id);
			}
		}
	};
}();
