/**
 * @class Sb.TopMessageBox
 * <p>Utility class to display messages at the top of page.<p/>
 * <p>Example usage:</p>
 *<pre><code>
Sb.TopMessageBox.show('Sitebuilder works in Trial mode.');
</code></pre>
 * @singleton
 */
Sb.TopMessageBox = function() {
	var el;

	return Ext.apply(new Ext.util.Observable, {

		/**
		 * Returns a reference to element
		 * @return {Ext.Element} The element
		 */
		getEl: function() {
			return el;
		},

		/**
		 * Displays a message box with specific message.
		 * @param {String} msg The message box body text
		 */
		show: function(msg) {
			if (!el) {
				el = Ext.getBody().insertFirst({
					cls: 'sb-top-message-box',
					cn: {
						cls: 'sb-top-message sb-top-message-warning',
						cn: {
							cls: 'sb-top-message-text'
						}
					}
				});
				Ext.EventManager.onWindowResize(this.onResize, this);
			}

			el.update(msg);

			if (!el.isVisible()) {
				el.show();
			}

			this.onResize();
		},

		/**
		 * Returns true if the message box is currently displayed
		 * @return {Boolean} True if the message box is visible, else false
		 */
		isVisible: function() {
			return el && el.isVisible();
		},

		/**
		 * Hides the message box if it is displayed
		 */
		hide: function() {
			if (this.isVisible()) {
				el.hide();
				this.onResize();
			}
		},

		onResize: function() {
			var w = this.isVisible() ? el.getWidth() : 0;
			var h = this.isVisible() ? el.getHeight() : 0;
			this.fireEvent('resize', this, w, h);
		}
	});
}();
