/**
 * @class Sb.editor.component.Image
 * @extends Sb.editor.component.Base
 * Class for image component
 * @constructor
 * @param {Object} config The config object
 * @xtype image_component
 */
Sb.editor.component.Image = Ext.extend(Sb.editor.component.Base, {
	removeConfirmation: false,

	onRender: function() {
		Sb.editor.component.Image.superclass.onRender.apply(this, arguments);
		this.imageEl = this.contentElement.createChild({
			tag: 'img',
			src: this.image || Ext.BLANK_IMAGE_URL,
			alt: ''
		});
	},

	initComponent: function() {
		Sb.editor.component.Image.superclass.initComponent.apply(this, arguments);
		this.removeTitle = SbGetLocaleByKey('hideWidgetTitle');
	},

	getEditPanel: function() {
		if (!Sb.editor.component.Image.editPanel) {
			Sb.editor.component.Image.editPanel = new Sb.editor.component.ImageEditPanel();
		}
		return Sb.editor.component.Image.editPanel;
	},

	onStartEdit: function() {
		Sb.editor.component.Image.superclass.onStartEdit.apply(this);
		this.startImage = this.image;
	},

	onCancelEdit: function() {
		Sb.editor.component.Image.superclass.onCancelEdit.apply(this);
		this.setImage(this.startImage);
	},

	/**
	 * Sets this Image's src
	 * @param {String} image The path to an image
	 * @return {Sb.editor.component.Image} this
	 */
	setImage: function(image) {
		this.image = image;
		if (this.rendered) {
			this.imageEl.set({'src': image || Ext.BLANK_IMAGE_URL});
		}
		return this;
	},

	initDD: function() {
		this.dd = new Ext.dd.DD(this);
		this.dd.setOuterHandleElId(this.ddEl);
		this.dd.component = this;
	}
});
Ext.reg('image_component', Sb.editor.component.Image);