/**
 * Class for image component edit panel
 *
 * @class Sb.editor.component.ImageEditPanel
 * @extends Sb.editor.component.BaseEditPanel
 */
Sb.editor.component.ImageEditPanel = Ext.extend(Sb.editor.component.BaseEditPanel, {
	cls: 'sb-component-edit-panel-image',
	autoHeight: true,
	width: 300,

	initComponent: function() {
		Ext.applyIf(this, {
			items: {
				xtype: 'form',
				ref: 'formPanel',
				fileUpload: true,
				labelAlign: 'top',
				items: {
					xtype: 'fileuploadfield',
					name: 'uploadfile',
					msgTarget: 'under',
					anchor: '0',
					regex: new RegExp('\\.(' + Sb.Config.imageValidExtensions.join('|') + ')$', 'i'),
					regexText: SbGetLocaleByKey('imageUploadErrorExtensionInvalid'),
					fieldLabel: SbGetLocaleByKey('componentImageUploadFieldTitle'),
					buttonText: SbGetLocaleByKey('browseButtonText'),
					emptyText: SbGetLocaleByKey('clickToBrowseAndUploadFile'),
					listeners: {
						scope: this,
						fileselected: this.onImageSelected
					}
				}
			}
		});

		Sb.editor.component.ImageEditPanel.superclass.initComponent.apply(this, arguments);
	},

	show: function(component) {
		Sb.editor.component.TextEditPanel.superclass.show.apply(this, arguments);
	},

	onImageSelected: function(field, value) {
		if ('' === value) {
			return;
		}

		var form = this.formPanel.form;
		form.submit({
			url: this.component.uploadAction,
			waitMsg: SbGetLocaleByKey('uploadingImage'),
			scope: this,
			success: function(fp, action) {
				this.component.setImage(this.component.uploadPath + '/' + action.result.fileName);
				form.el.dom.reset();
			},
			failure: function(fp, action) {
				if (action.result) {
					field.markInvalid(SbGetLocaleByKey(action.result.message));
				}
			}
		});
	}
});