/**
 * @class Sb.model.ContactWidget
 * @extends Sb.model.Widget
 * Class for contact widget model
 * @constructor
 * @param {Object} config The configuration options for the widget model
 */
Sb.model.ContactWidget = Ext.extend(Sb.model.Widget, {

	constructor: function(config) {
		config = Ext.apply({
			type: 'contact'
		}, config);

		this.fields = [];

		Sb.model.ContactWidget.superclass.constructor.call(this, config);
	},

	indexOf: function(name) {
        var index = -1;
		Ext.each(this.fields, function(field, i) {
			if (field.name == name) {
				index = i;
				return false;
			}
		});
		return index;
	},

	addField: function(attrs) {
		this.fields.push(attrs);
		this.fireEvent('change', this);
	},

	deleteField: function(name) {
        var index = this.indexOf(name);
        if (index == -1) {
            return;
        }

        this.fields.splice(index, 1);
		this.fireEvent('change', this);
	},

	insertField: function(name, newIndex) {
        var index = this.indexOf(name);
        if (index == -1 || index == newIndex) {
            return;
        }

		var field = this.fields[index];
        this.fields.splice(index, 1);
        this.fields.splice(newIndex, 0, field);
		this.fireEvent('change', this);
	},

	updateField: function(name, attrs) {
        var index = this.indexOf(name);
        if (index == -1) {
            return;
        }

		var field = this.fields[index];
		Ext.apply(field, attrs);
		this.fireEvent('change', this);
	},

	unserialize: function(data) {
		var isChanged = false;

		if (Ext.isArray(data.fields)) {
			this.fields = [];
			Ext.each(data.fields, function(field) {
				this.fields.push(Ext.apply({}, field));
			}, this);
			delete data.fields;
			isChanged = true;
		}

		var isDataChanged = Sb.model.ContactWidget.superclass.unserialize.call(this, data);
		if (!isDataChanged && isChanged) {
			this.fireEvent('change', this);
		}

		return isDataChanged || isChanged;
	},

	serialize: function() {
		var data = Sb.model.ContactWidget.superclass.serialize.call(this);
		delete data.widgets;
		data.fields = [];
		Ext.each(this.fields, function(field) {
			data.fields.push(Ext.apply({}, field));
		});

		return data;
	}
});
