/**
 * @class Sb.model.RemotingProvider
 */
Sb.model.RemotingProvider = Ext.extend(Ext.direct.RemotingProvider, {

	constructor: function(config) {
		Sb.model.RemotingProvider.superclass.constructor.call(this, config);

		this.on({
			beforecall	: this.onBeforeCall,
			data		: this.onReceiveData,
			scope		: this
		});

		/**
		 * Counts calls of API methods.
		 *
		 * @type Number
		 * @property callCounter
		 */
		this.callCounter = 0;

		this.addEvents(
			/**
			 * Fires when last call, from all previously started, will be finished.
			 *
			 * @event afterlastcall
			 */
			'afterlastcall'
		);
	},

	/**
	 * Runs after last call of all currently active asynchronious calls.
	 *
	 * @param {Function} Callback, that will be called immediatelly or after last call.
	 * @param {Object} Scope of the callback
	 */
	runAfterLastCall: function(fn, scope) {
		if (0 == this.callCounter) {
			fn.call(scope);
		} else {
			this.on('afterlastcall', fn, scope, {single: true});
		}
	},

	/**
	 * Fires before each remote method call.
	 *
	 * @see {Ext.direct.RemotingProvider::beforecall}
	 */
	onBeforeCall: function(me, transaction, meta) {
		this.callCounter++;
	},

	/**
	 * Fires after each remote method data receive.
	 *
	 * @see {Ext.direct.RemotingProvider::data}
	 */
	onReceiveData: function(me, e) {
		this.callCounter--;
		if (0 == this.callCounter) {
			this.fireEvent('afterlastcall');
		}
		if (e.redirect) {
			window.location = e.redirect;
			return;
		}

		var message 	= '',
			format		= Ext.util.Format,
			encode		= format.htmlEncode,
			nl2br		= format.nl2br,
			key			= SbGetLocaleByKey,
			exceptions	= Ext.Direct.exceptions;

		if ('exception' == e.type || e.isLogErrors) {
			Sb.Loading.hide();
			Ext.getBody().unmask();
			switch (e.code) {
				case exceptions.TRANSPORT:
					message = encode(key('UnableConnectToServerErrorMessage'));
					break;
				case exceptions.PARSE:
					message = encode(key('InvalidServerResponseErrorMessage'));
					break;
				default:
					message = encode(key('GenericServerErrorMessage')) +
								'<div class="sb-error-details">' + encode(e.message) + '</div>';
					if (e.where) {
						message += '<div class="sb-error-stacktrace">' + encode(key('Stacktrace')) + ':<br/>' +
							nl2br(encode(e.where)) + '</div>';
					}
					break;
			}
			Ext.Msg.show({
				title    : key('errorMessageBoxTitle'),
				msg      : message,
				closable : false,
				buttons  : Ext.Msg.OK,
				icon     : Ext.Msg.ERROR
			});
		}
	}
});
Ext.Direct.PROVIDERS['sbremoting'] = Sb.model.RemotingProvider;