/**
 * @class Sb.widget.Breadcrumbs
 * @extends Sb.widget.Widget
 * Class for Breadcrumbs widget
 * @xtype breadcrumbs_widget
 */
Sb.widget.Breadcrumbs = Ext.extend(Sb.widget.Widget, {
	/**
	 * @cfg {Sb.widget.Breadcrumbs} model
	 * The {@link Sb.widget.Breadcrumbs} to bind this Widget to.
	 */

	cls			: 'sb-widget-breadcrumbs',
	hasEditMenu	: false,

	onRender: function() {
		Sb.widget.Breadcrumbs.superclass.onRender.apply(this, arguments);
		this.refresh();
	},

	refresh: function() {
		this.refreshCode();
		this.refreshStyle();
	},

	refreshCode: function() {
		var	startPage		= Sb.Editor.model.rootPage.getFirstVisiblePage(),
			selfAndParents	= Sb.Editor.siteView.currentPage.getSelfAndParents(),
			pages 			= [startPage].concat(selfAndParents),
			lastIndex		= pages.length - 1,
			data			= this.model.data,
			encode			= Ext.util.Format.htmlEncode,
			iconCls			= data.startPageTitle ? 'icon-with-title' : 'icon';

		this.cleanInternalListeners();
		this.update('');
		if (data.isShowStartIcon) {
			this.widgetContentEl.createChild({
				tag	: 'a',
				cls	: iconCls,
				href: '#' + escape(startPage.getFileName())
			});
		}
		Ext.each(pages, function(page, index) {
			var isFirst			= 0 == index,
				isLast			= lastIndex == index,
				title			= encode(isFirst ? data.startPageTitle : page.data.title),
				itemEl			= null,
				isShowTitle		= '' != title,
				isShowSeparator	= true;

			if (isFirst && !data.isShowStartIcon && !isShowTitle) {
				isShowSeparator = false;
			}

			if (!isLast) {
				if (isShowTitle) {
					itemEl = this.widgetContentEl.createChild({
						tag	: 'a',
						cls	: 'page',
						href: '#' + escape(page.getFileName()),
						html: title
					});
				}
				if (isShowSeparator) {
					this.widgetContentEl.createChild({
						tag : 'span',
						cls	: 'separator',
						html: Ext.util.Format.htmlEncode(data.separator)
					});
				}
			} else {
				itemEl = this.widgetContentEl.createChild({
					tag	: 'span',
					cls	: 'page',
					html: title
				});
			}

			if (null != itemEl) {
				this.addInternalListener(page, 'change', function() {
					title = encode(isFirst ? data.startPageTitle : page.data.title);
					itemEl.update(title);
				});
			}
		}, this);
	},

	/**
	 * Updates CSS for breadcrumbs widget.
	 */
	refreshStyle: function() {
		var model				= this.model,
			fontSize			= model.data.fontSize,
			iconHeight			= 16,
			maxLineHeightRatio	= 1.44, //ratio for Arial Black as biggest font
			lineHeight			= Math.ceil(Math.max(fontSize * maxLineHeightRatio, iconHeight)),
			data				= Ext.apply({
				className	: '#' + this.widgetContentEl.getAttribute('id'),
				lineHeight	: lineHeight
			}, model.data);

		Sb.StyleManager.addStyleSheet(
			this.getType().getCssTemplate().apply(data),
			'widget-breadcrumbs',
			this.model.data.uuid
		);

		if (Sb.Editor.Ui.editComponent) {
			this.getEditPanel().reanchor();
		}
	},

	initEvents: function() {
		Sb.widget.Breadcrumbs.superclass.initEvents.call(this);

		this.mon(Sb.Editor.model.rootPage, 'change', this.refreshCode, this);
		this.mon(this.model, 'save', this.onModelSave, this);
		this.mon(this.model, 'propertychange', function(key) {
			if (/^font(Family|Size|Color)|decoration(Bold|Italic|Underline)$/.test(key)) {
				this.refreshStyle();
			} else {
				this.refreshCode();
			}
		}, this);
	},

	onCompleteEdit: function() {
		this.model.saveIfChanged(this.memento);
	},

	onModelSave: function() {
		Sb.Editor.Ui.mainWindow.statusBar.setMessage(
			SbGetLocaleByKey('messageChangesSaved')
		);
	},

	onDocumentClick: function(event) {
		if (event.getTarget('.x-combo-list') || event.getTarget('.sb-color-dropdown')) {
			return;
		}

		Sb.widget.Breadcrumbs.superclass.onDocumentClick.call(this, event);
	}

});

Ext.reg('breadcrumbs_widget', Sb.widget.Breadcrumbs);