/**
 * @class Sb.widget.Contact
 * @extends Sb.widget.Widget
 * Class for Contact widget
 * @constructor
 * @param {Object} config The config object
 * @xtype contact_widget
 */
Sb.widget.Contact = Ext.extend(Sb.widget.Widget, {
	cls: 'sb-widget-contact',

	hasEditMenu: false,

	/**
	 * The template to use when rendering the content of Widget.
	 * @property contentTpl
	 * @type Ext.XTemplate
	 */
	contentTpl: null,

	initComponent: function() {
		Sb.widget.Contact.superclass.initComponent.apply(this, arguments);

		this.contentTpl = new Ext.XTemplate(
			'<form id="widget-{uuid}-form">' +
				'<tpl for="fields">',
				'<div class="form-item">' +
					'<label class="form-item-label" for="widget-{parent.uuid}-field-{name}">' +
						'{title:htmlEncode}' +
						'<tpl if="required">' +
							' <span class="form-required">*</span>' +
						'</tpl>' +
					'</label>' +
					'<tpl if="type==\'textfield\' || type==\'email\'">' +
					'<input id="widget-{parent.uuid}-field-{name}" class="form-item-textfield" type="text" name="{name}" />' +
					'</tpl>' +
					'<tpl if="type==\'textarea\'">' +
					'<textarea id="widget-{parent.uuid}-field-{name}" class="form-item-textarea" name="{name}"></textarea>' +
					'</tpl>' +
				'</div>' +
				'</tpl>' +
				'<div class="form-item">' +
					'<label class="form-item-label" for="widget-{uuid}-captcha">' +
					Ext.util.Format.htmlEncode(SbGetLocaleByKey('widgetContactCaptchaFieldTitle')) + ' <span class="form-required">*</span>' +
					'</label>' +
					'<div class="form-item-captcha">' +
						'<img src="' + Sb.Config.baseUrl + '/images/captcha.jpg">' +
						'<div>' +
							'<input id="widget-{uuid}-captcha" type="text" name="captcha" size="6" /> ' +
							'<a href="#reload_captcha">' + Ext.util.Format.htmlEncode(SbGetLocaleByKey('widgetContactCaptchaReload')) + '</a>' +
						'</div>' +
					'</div>' +
				'</div>' +
				'<div class="form-note">' +
					Ext.util.Format.htmlEncode(SbGetLocaleByKey('widgetContactFormNote', ' * ')) +
				'</div>' +
				'<input type="submit" class="form-submit" value="{buttonText:htmlEncode}" />' +
			'</form>'
		);
	},

	onRender: function() {
		Sb.widget.Contact.superclass.onRender.apply(this, arguments);
		this.contentElement.mask();
	},

	renderContent: function() {
		return this.contentTpl.apply(this.model.serialize());
	},

	initEvents: function() {
		Sb.widget.Contact.superclass.initEvents.call(this);
		this.mon(this.model, 'change', this.update, this);
	},

	update: function() {
		Sb.widget.Contact.superclass.update.call(this, this.renderContent());
	},

	onCompleteEdit: function() {
		this.model.saveIfChanged(this.memento);
	},

	onDocumentClick: function(event) {
		if (event.getTarget('.x-combo-list')) {
			return;
		}

		Sb.widget.Header.superclass.onDocumentClick.call(this, event);
	}
});
Ext.reg('contact_widget', Sb.widget.Contact);
