/**
 * @class Sb.widget.ContactEditPanel
 * @extends Sb.widget.WidgetEditTabPanel
 * Class for contact widget edit panel
 * @constructor
 * @param {Object} config The config object
 */
Sb.widget.ContactEditPanel = Ext.extend(Sb.widget.WidgetEditTabPanel, {
	initComponent: function() {
		this.recipientsField = new Ext.form.TextField({
			fieldLabel	: SbGetLocaleByKey('widgetContactRecipientsFieldTitle'),
			anchor		: '100%',
			allowBlank	: false,
			maxLength	: 255,
			vtype		: 'emailMulti',
			msgTarget	: 'under',
			listeners	: {
				scope: this,
				valid: function(field) {
					this.widget.model.unserialize({
						recipients: field.getValue()
					});
				}
			}
		});

		this.subjectField = new Ext.form.TextField({
			fieldLabel	: SbGetLocaleByKey('widgetContactSubjectFieldTitle'),
			anchor		: '100%',
			allowBlank	: false,
			maxLength	: 255,
			msgTarget	: 'under',
			listeners	: {
				scope: this,
				valid: function(field) {
					this.widget.model.unserialize({
						subject: field.getValue()
					});
				}
			}
		});

		this.replyField = new Ext.form.TextArea({
			hideLabel	: true,
			anchor		: '100%',
			maxLength	: 255,
			listeners	: {
				scope: this,
				valid: function(field) {
					this.widget.model.unserialize({
						reply: field.getValue()
					});
				}
			}
		});

		this.buttonTextField = new Ext.form.TextField({
			fieldLabel	: SbGetLocaleByKey('widgetContactButtonTextFieldTitle'),
			anchor		: '100%',
			allowBlank	: false,
			maxLength	: 40,
			msgTarget	: 'under',
			listeners	: {
				scope: this,
				valid: function(field) {
					this.widget.model.unserialize({
						buttonText: field.getValue()
					});
				}
			}
		});

		this.fieldTitleField = new Ext.form.TextField({
			xtype: 'textfield',
			fieldLabel: SbGetLocaleByKey('widgetContactFieldTitleFieldTitle'),
			name: 'title',
			allowBlank: false,
			maxLength: 100,
			anchor: '100%',
			msgTarget: 'under',
			listeners: {
				scope: this,
				valid: function(field) {
					var node = this.fieldsSM.getSelectedNode();
					node.setText(Ext.util.Format.htmlEncode(
						Ext.util.Format.ellipsis(field.getValue(), 28 - node.getDepth() * 2)
					));
					node.attributes.title = field.getValue();
					this.widget.model.updateField(node.id, {
						title: field.getValue()
					});
				}
			}
		});
		this.fieldTypeField = new Ext.form.ComboBox({
			fieldLabel: SbGetLocaleByKey('widgetContactFieldTypeFieldTitle'),
			name: 'type',
			msgTarget: 'under',
			anchor: '100%',
			store: [
				['textfield', SbGetLocaleByKey('widgetContactFieldTypeTextfield')],
				['textarea', SbGetLocaleByKey('widgetContactFieldTypeTextarea')],
				['email', SbGetLocaleByKey('widgetContactFieldTypeEmail')]
			],
			listeners: {
				scope: this,
				select: function(combo, record) {
					var node = this.fieldsSM.getSelectedNode();
					node.attributes.type = combo.getValue();
					this.widget.model.updateField(this.fieldsSM.getSelectedNode().id, {
						type: combo.getValue()
					});
				}
			}
		});
		this.fieldRequiredField = new Ext.form.Checkbox({
			name: 'required',
			hideLabel: true,
			boxLabel: SbGetLocaleByKey('widgetContactFieldRequiredFieldTitle'),
			listeners: {
				scope: this,
				check: function(checkbox, checked) {
					var node = this.fieldsSM.getSelectedNode();
					node.attributes.requred = checked;
					this.widget.model.updateField(this.fieldsSM.getSelectedNode().id, {
						required: checked
					});
				}
			}
		});

		this.fieldsSM = new Ext.tree.DefaultSelectionModel({
			listeners: {
				scope: this,
				selectionchange: function(sm, node) {
					if (!node) {
						return;
					}
					this.fieldTitleField.setValue(node.attributes.title);
					this.fieldTypeField.setValue(node.attributes.type);
					this.fieldRequiredField.setValue(node.attributes.required);
				}
			}
		});
		this.fields = new Ext.tree.TreeNode();

		this.addFieldButton = new Ext.Button({
			text: SbGetLocaleByKey('widgetContactAddFieldTitle'),
			tooltip: SbGetLocaleByKey('widgetContactAddFieldTooltip'),
			iconCls: 'sb-add-icon',
			handler : this.addField.createDelegate(this, [])
		});
		this.deleteFieldButton = new Ext.Button({
			text: SbGetLocaleByKey('widgetContactDeleteFieldTitle'),
			tooltip: SbGetLocaleByKey('widgetContactDeleteFieldTooltip'),
			iconCls: 'sb-delete-icon',
			handler : this.deleteField.createDelegate(this)
		});

		Ext.apply(this, {
			width: 510,
			cls: 'sb-widget-edit-panel-contact',
			items: [{
				cls: 'sb-widget-contact-settings-panel',
				title: SbGetLocaleByKey('widgetContactSettingsTabTitle'),
				autoHeight: true,
				layout: 'form',
				labelAlign: 'top',
				defaults: {
					validateOnBlur: false
				},
				items: [
					this.recipientsField,
					this.subjectField,
					this.buttonTextField
				],
				listeners: {
					scope: this,
					activate: this.initSettingsTab
				}
			}, {
				cls: 'sb-widget-contact-fields-panel',
				title: SbGetLocaleByKey('widgetContactFieldsTabTitle'),
				autoHeight: true,
				layout: 'column',
				defaults: {
					buttonAlign: 'left'
				},
				items: [{
					columnWidth: .6,
					xtype: 'treepanel',
					baseCls: 'sb-pages-tree',
					height: 161,
					autoScroll: true,
					animate: true,
					containerScroll: true,
					enableDD: true,
					lines: false,
					rootVisible: false,
					root: this.fields,
					selModel: this.fieldsSM,
					listeners: {
						scope: this,
						movenode: function(tree, node, oldParent, newParent, index) {
							this.widget.model.insertField(node.id, index);
							node.select();
						},
						startdrag: function(panel, node, e) {
							var el = panel.dragZone.proxy.el;
							el.disableShadow();
							el.setXY(el.getXY());
							var ghost = panel.dragZone.proxy.ghost;
							ghost.addClass('sb-pages-tree-drag-ghost');
							ghost.setWidth(Ext.get(node.ui.wrap).getWidth());
						},
						beforemovenode: function(tree, node, oldParent, newParent, index) {
							return node.getUI().allowMoveToNode(newParent);
						}
					},
					buttons: [this.addFieldButton, this.deleteFieldButton]
				}, {
					columnWidth: .4,
					layout: 'form',
					labelAlign: 'top',
					defaults: {
						validateOnBlur: false
					},
					items: [this.fieldTitleField, this.fieldTypeField, this.fieldRequiredField]
				}],
				listeners: {
					scope: this,
					activate: this.initFieldsTab
				}
			}, {
				cls: 'sb-widget-contact-reply-panel',
				title: SbGetLocaleByKey('widgetContactReplyTabTitle'),
				autoHeight: true,
				layout: 'form',
				labelAlign: 'top',
				items: this.replyField,
				listeners: {
					scope: this,
					activate: this.initReplyTab
				}
			}]
		});

		Sb.widget.ContactEditPanel.superclass.initComponent.apply(this, arguments);
	},

	show: function() {
		this.loadedTabs = {};
		Sb.widget.ContactEditPanel.superclass.show.apply(this, arguments);
	},

	initSettingsTab: function() {
		this.reanchor();

		if (this.loadedTabs['settings']) {
			return;
		}
		this.loadedTabs['settings'] = true;

		var data = this.widget.model.data;
		this.recipientsField.setValue(data.recipients);
		this.subjectField.setValue(data.subject);
		this.buttonTextField.setValue(data.buttonText);
	},

	initFieldsTab: function() {
		this.reanchor();

		if (this.loadedTabs['fields']) {
			return;
		}
		this.loadedTabs['fields'] = true;

		this.fields.removeAll(true);
		this.fieldAutoId = 0;
		Ext.each(this.widget.model.fields, function(field) {
			if ((m = field.name.match(/^field(\d+)$/)) && (parseInt(m[1]) > this.fieldAutoId)) {
				this.fieldAutoId = parseInt(m[1]);
			}
			this.fields.appendChild(new Ext.tree.TreeNode({
				id: field.name,
				text: Ext.util.Format.htmlEncode(Ext.util.Format.ellipsis(field.title, 26)),
				title: field.title,
				required: field.required,
				type: field.type,
				leaf: true,
				uiProvider: Sb.widget.ContactFieldsTreeNodeUI
			}));
		}, this);
		this.fields.firstChild.select();

		this.deleteFieldButton.setDisabled(this.fields.childNodes.length < 2);
	},

	initReplyTab: function() {
		this.reanchor();

		if (this.loadedTabs['reply']) {
			return;
		}
		this.loadedTabs['reply'] = true;

		this.replyField.setValue(this.widget.model.data.reply);
	},

	addField: function(attrs) {
		attrs = Ext.apply({
			name: 'field' + (++this.fieldAutoId),
			title: SbGetLocaleByKey('widgetContactNewFieldTitle'),
			type: 'textfield',
			required: false
		}, attrs || {});

		this.fields.appendChild(new Ext.tree.TreeNode({
			id: attrs.name,
			text: Ext.util.Format.htmlEncode(Ext.util.Format.ellipsis(attrs.title, 26)),
			title: attrs.title,
			required: attrs.required,
			type: attrs.type,
			leaf: true,
			uiProvider: Sb.widget.ContactFieldsTreeNodeUI
		})).select();

		this.widget.model.addField(attrs);
		this.deleteFieldButton.setDisabled(this.fields.childNodes.length < 2);
	},

	deleteField: function() {
		var nodeForDelete = this.fieldsSM.getSelectedNode();
		if (!nodeForDelete) {
			return;
		}

		var nodeForSelect = nodeForDelete.nextSibling || nodeForDelete.previousSibling;

		this.widget.model.deleteField(nodeForDelete.id);
		nodeForDelete.parentNode.removeChild(nodeForDelete);
		nodeForSelect.select();
		this.deleteFieldButton.setDisabled(this.fields.childNodes.length < 2);
	}
});
