/**
 * @class Sb.widget.HeaderEditPanel
 * @extends Sb.widget.WidgetEditTabPanel
 * Class for header widget edit panel
 * @constructor
 * @param {Object} config The config object
 */
Sb.widget.HeaderEditPanel = Ext.extend(Sb.widget.WidgetEditPanel, {
	/**
	 * Image selection radiog roup
	 * @type Ext.form.RadioGroup
	 * @property imageSelection
	 */
	/**
	 * Show elements checkbox group
	 * @type Ext.form.CheckboxGroup
	 * @property showElements
	 */
	/**
	 * Image list panel
	 * @type Ext.Panel
	 * @property imageListPanel
	 */
	/**
	 * File upload panel
	 * @type Ext.FormPanel
	 * @property imageUploadPanel
	 */
	/**
	 * Image height panel
	 * @type Ext.Panel
	 * @property imageHeightPanel
	 */
	/**
	 * Image size panel
	 * @type Ext.Panel
	 * @property imageSizePanel
	 */

	/**
	 * @cfg {Number} imageListPageSize Image per page in images list.
	 */
	imageListPageSize: 10,

	initComponent: function() {
		this.headerImageStore = new Ext.data.JsonStore({
			typeStore: 'library',
			fields: ['name', 'path', 'keywords', 'isRecommended'],
			baseParams: {
				filter: {}
			}
		});
		this.headerImageCustomStore = new Ext.data.JsonStore({
			typeStore: 'custom',
			fields: ['name', 'time', 'path'],
			listeners: {
				scope: this,
				remove: function(store, record, index) {
					var newData = store.proxy.data;
					newData.splice(index, 1);
					store.proxy = new Ext.ux.data.PagingMemoryProxy(newData);
				}
			}
		});
		var fontStorage = new Ext.data.ArrayStore({
			fields: ['value'],
			data: [['Andale Mono'], ['Arial'], ['Arial Black'], ['Book Antiqua'], ['Comic Sans MS'], ['Courier New'],
				['Georgia'], ['Helvetica'], ['Impact'], ['Symbol'], ['Tahoma'], ['Terminal'], ['Times New Roman'],
				['Trebuchet MS'], ['Verdana'], ['Webdings'], ['Wingdings']]
		});
		var fontSizeStorage = new Ext.data.ArrayStore({
			fields: ['value'],
			data: [['8'], ['9'], ['10'], ['11'], ['12'], ['14'], ['16'], ['18'], ['20'], ['22'], ['24'], ['26'], ['28'],
				['36'], ['48'], ['72']
			]
		});

		Ext.apply(this, {
			frame: true,
			width: 640,
			cls: 'sb-widget-edit-panel-header',
			items: [{
				height: 87,
				layout: 'column',
				defaults: {
					layout: 'form',
					labelAlign: 'top'
				},
				items: [{
					width: 157,
					items: [{
						ref: '../../imageSelection',
						xtype: 'radiogroup',
						fieldLabel: SbGetLocaleByKey('widgetHeaderImageSelectionTitle'),
						labelSeparator: '',
						columns: 1,
						defaults: {
							xtype: 'radio',
							name: 'selection'
						},
						items: [{
							boxLabel: SbGetLocaleByKey('widgetHeaderImageSelectionLibraryTitle'),
							inputValue: 'library'
						}, {
							boxLabel: SbGetLocaleByKey('widgetHeaderImageSelectionFileTitle'),
							inputValue: 'file'
						}, {
							boxLabel: SbGetLocaleByKey('widgetHeaderImageSelectionNoTitle'),
							inputValue: 'no'
						}],
						listeners: {
							scope: this,
							change: this.onImageSelectionChange
						}
					}]
				}, {
					width: 238,
					defaults: {
						layout: 'form',
						labelAlign: 'top'
					},
					items: [{
						ref: '../../imageListPanel',
						items: {
							ref: 'imageList',
							xtype: 'sbselectbox',
							fieldLabel: SbGetLocaleByKey('widgetHeaderImageListTitle'),
							labelSeparator: '',
							triggerAction: 'all',
							mode: 'local',
							width: 235,
							valueField: 'path',
							cls: 'sb-header-images',
							ctCls: 'sb-header-images-control',
							listClass: 'sb-header-images-list',
							listWidth: 442,
							maxHeight: 338,
							lazyInit: false,
							listEmptyText: SbGetLocaleByKey('widgetHeaderImageListNoMatch'),
							tpl: new Ext.XTemplate(
								'<tpl for=".">' +
								'<div class="sb-selectbox-list-item sb-header-images-list-item" >' +
									'<div>' +
										'<img src="{path}" height="57">' +
										'<div class="sb-selectbox-list-item-delete"><span>X</span></div>' +
									'</div>' +
								'</div></tpl>'
							),
							itemSelector: 'div.sb-selectbox-list-item',
							collapse: function() {
								if (this.dialog && this.dialog.isVisible()) {
									return;
								}
								Sb.form.SelectBox.superclass.collapse.call(this);
							},
							listeners: {
								scope: this,
								select: function(combo, record) {
									this.imageSizePanel.fitCheckbox.enable();
									if ('file' == this.imageSelection.getValue().getGroupValue()) {
										this.widget.model.unserialize({
											imageName: '',
											imagePath: '/' + Sb.Config.headerPath + '/' + record.data.name,
											imageTime: record.data.time
										});
									} else {
										this.widget.model.unserialize({
											imageName: record.data.name,
											imagePath: ''
										});
									}
								},
								afterrender: function(selectbox) {
									selectbox.isClickedDelete = false;
									selectbox.header = selectbox.list.createChild(
										{cls: 'x-combo-list-hd'},
										selectbox.innerList
									);
									selectbox.searchField = new Ext.form.TextField({
										emptyText: SbGetLocaleByKey('widgetHeaderImageListEmptySearch'),
										width: 220,
										renderTo: selectbox.header,
										listeners: {
											scope: this,
											valid: function(field) {
												if (this.hidden) {
													return;
												}
												var words = field.getValue().trim().split(/[~!@#%^&:%_, <>\-\/]/);
												Ext.iterate(words, function(word, index) {
													words[index] = Ext.escapeRe(word);
												});
												var newKeywords = new RegExp('(^|,)(' + words.join('|') + ')', 'ig');
												var currentKeywords = this.headerImageStore.baseParams.filter.keywords;
												if (currentKeywords && currentKeywords.toString() == newKeywords.toString()) {
													return;
												}
												this.headerImageStore.baseParams.filter.keywords = newKeywords;
												this.headerImageStore.load({
													params: {
														start: 0,
														limit: this.imageListPageSize
													}
												});
											}
										}
									});

									var headerShow = 'all';
									selectbox.filterRecommended = new Ext.Container({
										renderTo: selectbox.header,
										cls: 'sb-show-headers',
										items: [{
											xtype: 'label',
											html: SbGetLocaleByKey('showHeaders'),
											cls: 'sb-show-headers-title'
										}, {
											xtype: 'radio',
											name: 'showHeaders',
											boxLabel: SbGetLocaleByKey('allHeaders'),
											value: '',
											checked: headerShow == 'all',
											listeners: {
												scope: this,
												check: function(radio, checked) {
													if (!checked) {
														return;
													}
													selectbox.searchField.enable();
													this.headerImageStore.baseParams.filter.isRecommended = /true|false/;
													selectbox.searchField.fireEvent('valid', selectbox.searchField);
												}
											}
										}, {
											xtype: 'radio',
											name: 'showHeaders',
											boxLabel: SbGetLocaleByKey('recommendedHeaders'),
											value: 'recommended',
											checked: headerShow == 'recommended',
											listeners: {
												scope: this,
												check: function(radio, checked) {
													if (!checked) {
														return;
													}
													selectbox.searchField.disable();
													this.headerImageStore.baseParams.filter.isRecommended = /true/;
													this.headerImageStore.baseParams.filter.keywords = '';
													this.headerImageStore.load({
														params: {
															start: 0,
															limit: this.imageListPageSize
														}
													});
												}
											}
										}]
									});
									selectbox.assetHeight += selectbox.header.getHeight();

									selectbox.footer = selectbox.list.createChild({cls: 'x-combo-list-ft'});
									selectbox.pageTb = new Ext.PagingToolbar({
										store: selectbox.store,
										pageSize: this.imageListPageSize,
										renderTo: selectbox.footer,
										listeners: {
											afterrender: function(pageTb) {
												pageTb.refresh.hide();
											}
										}
									});
									if (Ext.isIE7) {
										selectbox.footer.repaint();
									}
									selectbox.assetHeight += selectbox.footer.getHeight();

									selectbox.view.mon(selectbox.view.getTemplateTarget(), {
										"mouseover": selectbox.view.onMouseOver,
										"mouseout": selectbox.view.onMouseOut,
										scope: selectbox.view
									});

									selectbox.view.on('mouseenter', function(dataView, index, node, evt) {
										var overHeaderName = selectbox.store.data.items[index].data.name;
										if (dataView.store.typeStore == 'library' ||
											selectbox.getValue().indexOf(overHeaderName) >= 0) {
											return;
										}
										var deleteButton = Ext.get(node).down('div').down('div.sb-selectbox-list-item-delete');
										deleteButton.show();
										deleteButton.on('click', function(){
											selectbox.isClickedDelete = true;
										});
									}, this);

									selectbox.view.on('mouseleave', function(dataView, index, node, evt) {
										if (selectbox.store.typeStore == 'library') {
											return;
										}
										var deleteButton = Ext.get(node).down('div').down('div.sb-selectbox-list-item-delete');
										deleteButton.hide();
										deleteButton.removeAllListeners();
									});

									selectbox.on('beforeselect', function(selectbox, record, index) {
										if (selectbox.isClickedDelete) {
											selectbox.isClickedDelete = false;
											selectbox.dialog = Ext.Msg.show({
												title	: SbGetLocaleByKey('widgetHeaderDialogTitleDeleteImage'),
												msg		: SbGetLocaleByKey('widgetHeaderDialogMsgConfirmDeleteImage'),
												closable: false,
												buttons	: Ext.Msg.YESNO,
												scope	: this,
												fn		: function(btn) {
													if (btn == 'yes') {
														this.onDeleteHeader(selectbox, record, index);
													}
												}
											});
											return false;
										}
									}, this);
								}
							}
						}
					}, {
						ref: '../../imageHeightPanel',
						layout: 'column',
						items: [{
							xtype: 'box',
							autoEl: 'span',
							cls: 'sb-widget-header-image-height-label',
							html: SbGetLocaleByKey('widgetHeaderImageHeightTitle')
						}, {
							ref			: 'heightField',
							xtype		: 'numberfield',
							allowBlank	: false,
							minValue	: 50,
							maxValue	: 500,
							width		: 40,
							fieldLabel	: SbGetLocaleByKey('widgetHeaderImageHeightTitle'),
							listeners: {
								scope: this,
								valid: function(textfield) {
									this.widget.model.unserialize({
										height: textfield.getValue()
									});
								}
							}
						}, {
							xtype: 'box',
							autoEl: 'span',
							cls: 'sb-widget-header-image-height-measure',
							html: SbGetLocaleByKey('px')
						}]
					}]
				}, {
					ref: '../imageSizePanel',
					width: 177,
					items: [{
						ref: 'fitCheckbox',
						xtype: 'checkbox',
						boxLabel: SbGetLocaleByKey('widgetHeaderImageFitSizeTitle'),
						listeners: {
							scope: this,
							check: function(checkbox, checked) {
								this.widget.model.unserialize({
									imageFit: checked ? 1 : 0
								});
							},
							afterrender: function(checkbox) {
								var fn = Sb.Editor.Ui.mainWindow.setHelperMessage.createDelegate(
									Sb.Editor.Ui.mainWindow, [SbGetLocaleByKey('widgetHeaderImageFitSizeTooltip')]
								);
								checkbox.el.on('mouseenter', fn);
								checkbox.el.on('mouseleave', Sb.Editor.Ui.mainWindow.restoreHelperMessage, Sb.Editor.Ui.mainWindow);

								checkbox.labelEl.on('mouseenter', fn);
								checkbox.labelEl.on('mouseleave', Sb.Editor.Ui.mainWindow.restoreHelperMessage, Sb.Editor.Ui.mainWindow);
							}
						}
					}, {
						ref: 'hintField',
						xtype: 'displayfield',
						hideLabel: true,
						value: SbGetLocaleByKey('widgetHeaderImageSizeHint', 0, 0)
					}]
				}]
			}, {
				ref: 'imageUploadPanel',
				xtype: 'form',
				cls: 'sb-widget-header-image-upload',
				fileUpload: true,
				labelAlign: 'top',
				items: {
					xtype: 'fileuploadfield',
					regex: new RegExp('\\.(' + Sb.Config.headerValidExtensions.join('|') + ')$', 'i'),
					msgTarget: 'under',
					anchor: '0',
					buttonText: SbGetLocaleByKey('widgetHeaderUploadButton'),
					fieldLabel: SbGetLocaleByKey('widgetHeaderUploadLabel'),
					emptyText: SbGetLocaleByKey('widgetHeaderUploadEmptyText'),
					labelSeparator: '',
					name: 'headerimage',
					listeners: {
						scope: this,
						fileselected: this.onUploadFile,
						afterrender: function(){
							this.imageUploadPanel.hide();
						}
					}
				}
			}, {
				layout: 'column',
				cls: 'sb-widget-header-show-elements',
				items: [{
					width: 157,
					html: SbGetLocaleByKey('widgetHeaderShowElements')
				}, {
					ref: '../showElements',
					xtype: 'checkboxgroup',
					width: 238,
					columns: 1,
					items: [{
						name: 'logo',
						boxLabel: SbGetLocaleByKey('widgetHeaderShowLogo'),
						listeners: {
							scope: this,
							check: function(check, checked) {
								this.widget.model.setProperty('logoIsHidden', !checked);
							}
						}
					}, {
						name: 'title',
						boxLabel: SbGetLocaleByKey('widgetHeaderShowTitle'),
						listeners: {
							scope: this,
							check: function(check, checked) {
								this.widget.model.setProperty('titleIsHidden', !checked);
							}
						}
					}, {
						name: 'subtitle',
						boxLabel: SbGetLocaleByKey('widgetHeaderShowSubtitle'),
						itemCls: 'sb-editor-panel-header-showsubtitle',
						listeners: {
							scope: this,
							check: function(check, checked) {
								this.widget.model.setProperty('subtitleIsHidden', !checked);
							}
						}
					}]
				}]
			}]
		});

		Sb.widget.HeaderEditPanel.superclass.initComponent.apply(this, arguments);
	},

	/**
	 * Delete custom header
	 */
	onDeleteHeader: function(selectbox, record, index) {

		Sb.SiteService.deleteHeader(record.get('name'), function(result, response) {
			if (result) {
				selectbox.store.removeAt(index);
				selectbox.pageTb.doRefresh();
				Sb.Editor.Ui.mainWindow.statusBar.setMessageInfo(SbGetLocaleByKey('widgetHeaderImageWasDeleted'));
			} else {
				Sb.Editor.Ui.mainWindow.restore();
				Sb.Editor.Ui.mainWindow.statusBar.setMessageError(SbGetLocaleByKey('widgetHeaderImageDeleteFailed').replace('{headerName}', record.get('name')));
			}
		});
	},

	onImageSelectionChange: function() {
		var selection = this.imageSelection.getValue().getGroupValue();
		var imageList = this.imageListPanel.imageList;

		if ('no' == selection) {
			this.onImageSelectionNo();
		} else {
			this.imageListPanel.show();
			this.imageSizePanel.show();

			if ('file' == selection) {
				this.onImageSelectionFile();
			} else {
				this.onImageSelectionLibrary();
			}

			if (this.widget.model.data.imageName != '') {
				imageList.setValue(Sb.Config.headersUrl + '/' + this.widget.model.data.imageName + '/preview.png');
			} else {
				imageList.setValue(
					Sb.Editor.model.getUrl()
					+ this.widget.model.data.imagePath.replace('/image_', '/thumbnail_image_')
					+ '?' + this.widget.model.data.imageTime
				);
			}
		}
	},

	onImageSelectionNo: function() {
		this.imageUploadPanel.hide();
		this.imageListPanel.hide();
		this.imageSizePanel.hide();
		this.imageHeightPanel.heightField.setValue(this.widget.model.data.height);
		this.imageHeightPanel.show();

		this.widget.model.unserialize({
			imageName: 'fallback',
			imagePath: ''
		});
		this.imageSizePanel.fitCheckbox.disable();
	},

	onImageSelectionFile: function() {
		var imageList = this.imageListPanel.imageList;
		imageList.filterRecommended.hide();
		imageList.searchField.hide();
		this.imageUploadPanel.show();
		imageList.bindStore(this.headerImageCustomStore);
		if (!imageList.store.proxy) {
			Sb.SiteService.getHeaders(function(result) {
				Ext.each(result, function(data) {
					data.path = Sb.Editor.model.getUrl() + '/' + Sb.Config.headerPath + '/thumbnail_' + data.name + '?' + data.time;
				});
				imageList.store.proxy = new Ext.ux.data.PagingMemoryProxy(result);
				this.onImageSelectionFile();
			}, this);
			return;
		}

		imageList.store.load({params: {start: 0, limit: this.imageListPageSize}});
	},

	onImageSelectionLibrary: function() {
		var imageList = this.imageListPanel.imageList;
		this.imageUploadPanel.hide();
		imageList.filterRecommended.show();
		imageList.searchField.show();
		imageList.bindStore(this.headerImageStore);
		if (!imageList.store.proxy) {
			Sb.SystemService.getHeaders(function(result) {
				Ext.each(result, function(data) {
					data.path = Sb.Config.headersUrl + '/' + data.name + '/preview.png';
				});
				imageList.store.proxy = new Ext.ux.data.PagingMemoryProxy(result);
				this.onImageSelectionLibrary();
			}, this);
			return;
		}

		imageList.store.load({params: {start: 0, limit: this.imageListPageSize}});
	},

	onHeaderLoaded: function() {
		if (this.widget.model.data.imageName == 'fallback') {
			this.imageSizePanel.hintField.hide();
			this.imageSizePanel.fitCheckbox.disable();
			return;
		}

		var img = new Image();
		img.src = this.widget.imageEl.getAttribute('src');
		this.imageSizePanel.fitCheckbox.enable();
		this.imageSizePanel.hintField.setValue(
			SbGetLocaleByKey('widgetHeaderImageSizeHint', img.width, img.height)
		).show();
	},

	show: function(widget) {
		Sb.widget.HeaderEditPanel.superclass.show.call(this, widget);

		var data = this.widget.model.data;
		this.imageSizePanel.fitCheckbox.setValue(data.imageFit == 1);
		this.imageSelection.setValue();
		if (data.imageName == '') {
			this.imageSelection.setValue('file');
		} else if (data.imageName == 'fallback'){
			this.imageSelection.setValue('no');
		} else {
			this.imageSelection.setValue('library');
		}
		var w = this.widget.contentElement.getWidth();
		this.imageUploadPanel.el.child('label').update(
			SbGetLocaleByKey('widgetHeaderUploadLabel', w)
		);

		this.showElements.setValue({
			logo: data.logoIsHidden == 0,
			title: data.titleIsHidden == 0,
			subtitle: data.subtitleIsHidden == 0
		});

		this.onHeaderLoaded();
	},

	onUploadFile: function(field, fieldValue) {
		var form = this.imageUploadPanel.getForm();
		if (!form.isValid()) {
			field.markInvalid(SbGetLocaleByKey('imageUploadErrorTypeInvalid'));
			return;
		}
		form.submit({
			url: 'Upload/Header',
			waitMsg: SbGetLocaleByKey('uploadingImage'),
			success: function(fp, action){
				var imageList = this.imageListPanel.imageList;
				this.widget.model.unserialize({
					imageName: '',
					imagePath: '/' + Sb.Config.headerPath + '/' + action.result.uploadedFileName,
					imageTime: action.result.time
				});
				imageList.store.proxy.destroy();
				delete imageList.store.proxy;
				this.onImageSelectionChange();
				this.imageSizePanel.fitCheckbox.enable();
				form.el.dom.reset();
			}.createDelegate(this),
			failure: function(fp, action){
				field.markInvalid(SbGetLocaleByKey(action.result.message));
			}
		});
	}
});