/**
 * @class Sb.widget.NavigationEditPanel
 * @extends Sb.widget.WidgetEditTabPanel
 * Class for navigation widget edit panel
 * @constructor
 * @param {Object} config The config object
 */
Sb.widget.NavigationEditPanel = Ext.extend(Sb.widget.WidgetEditTabPanel, {
	initComponent: function() {
		Ext.apply(this, {
			width: 535,
			autoHeight: true,
			cls: 'sb-widget-edit-panel-navigation',
			items: [{
				cls: 'sb-widget-navigation-levels-panel',
				hasHelperMessage: true,
				title: SbGetLocaleByKey('widgetNavigationLevelsTabTitle'),
				layout: 'form',
				autoHeight: true,
				labelAlign: 'top',
				items: {
					xtype: 'combo',
					id: 'navigation-level',
					fieldLabel: SbGetLocaleByKey('showMenuLevels'),
					itemCls: 'sb-navigation-level-select',
					name: 'bgPlace',
					mode: 'local',
					width: 250,
					editable: false,
					triggerAction: 'all',
					lazyInit: false,
					store: new Ext.data.ArrayStore({
						fields: ['value', 'display', 'message'],
						data: [['1-1', SbGetLocaleByKey('firstLevel'), SbGetLocaleByKey('widgetNavigationLevelMessage11')],
									['2-1', SbGetLocaleByKey('secondLevel'), SbGetLocaleByKey('widgetNavigationLevelMessage21')],
									['1-2', SbGetLocaleByKey('firstAndSecondLevel'), SbGetLocaleByKey('widgetNavigationLevelMessage12')],
									['3-1', SbGetLocaleByKey('thirdLevel'), SbGetLocaleByKey('widgetNavigationLevelMessage31')],
									['2-2', SbGetLocaleByKey('secondAndThirdLevels'), SbGetLocaleByKey('widgetNavigationLevelMessage22')],
									['1-3', SbGetLocaleByKey('allLevels'), SbGetLocaleByKey('widgetNavigationLevelMessage13')]]
					}),
					displayField: 'display',
					valueField: 'value',
					autoSelect: true,
					listeners: {
						scope: this,
						select: function(combo, record, index) {
							var value = combo.getValue().split('-');
							this.widget.model.unserialize({
								level: parseInt(value[0]),
								depth: parseInt(value[1])
							});
							this.setHelperMessage(record.get('message'));
						}
					}
				}
			},
			this.createMenuItemsTab()
			]
		});

		Sb.widget.NavigationEditPanel.superclass.initComponent.apply(this, arguments);

		this.tabs.on('tabchange', function(panel, tab) {
			this.toggleHelperMessage(tab.initialConfig.hasHelperMessage);
		}, this);
	},

	/**
	 * Generate menu items tab
	 *
	 * @return {Ext.Panel}
	 */
	createMenuItemsTab: function() {
		/**
		 * Menu items tab
		 *
		 * @type Ext.Panel
		 */
		this.menuItemsTab = new Ext.Panel({
			title		: SbGetLocaleByKey('widgetNavigationMenuItemsTabTitle'),
			layout		: 'column',
			cls			: 'sb-widget-navigation-items-panel',
			autoHeight	: true
		});
		this.menuItemsTab.on('render', this.renderMenuItemsTab, this, {single: true});
		return this.menuItemsTab;
	},

	/**
	 * Render menu items tab
	 */
	renderMenuItemsTab: function() {
		/**
		 * Possible link states
		 *
		 * @type Array
		 * @property linkStates
		 */
		this.linkStates		= ['Normal', 'Selected', 'Hovered'];

		/**
		 * Current selected link state
		 *
		 * @type String
		 * @property activeLinkState
		 */
		this.activeLinkState = '';

		/**
		 * Menu item alignments
		 *
		 * @type Array
		 * @property alignments
		 */
		this.alignments		= ['Left', 'Center', 'Right'];

		var smallMargin		= 6;
		var smallButtonWidth= smallMargin * 4;
		var smallCellWidth	= smallMargin * 12;
		var mediumMargin	= smallMargin * 2;
		var mediumCellWidth	= smallCellWidth * 2;

		var tabPanelWidth	= this.width - mediumMargin;
		var colorComboWidth	= smallCellWidth * 1.5;
		var linkStateWidth	= Math.floor(tabPanelWidth * 0.25 - 1);
		var contentWidth	= Math.floor(tabPanelWidth * 0.75 - 1);

		var widgetControlCls = 'sb-edit-control sb-edit-control-';

		// Create link state group
		var stateGroup = new Sb.form.FieldGroup({
			columnWidth		: .25,
			autoWidth		: false
		});
		var stateItems = [];
		Ext.each(this.linkStates, function (linkState, index) {
			var stateItem = new Ext.form.Radio({
				boxLabel		: SbGetLocaleByKey('widgetNavigationLinkState' + linkState),
				inputValue		: linkState,
				name			: 'stateItems'
			});
			stateItem.on('render', function() {
				stateItem.wrap.unselectable();
			}, stateItem, {single: true});
			stateItems.push(stateItem);
		});
		var stateRadioGroup = new Ext.form.RadioGroup({
			items			: stateItems,
			columns			: 1,
			width			: linkStateWidth,
			itemCls			: widgetControlCls + 'link-state',
			fieldLabel		: SbGetLocaleByKey('widgetNavigationLinkState'),
			labelSeparator	: ''
		});
		stateRadioGroup.on('change', function (select, option) {
			var isNormal	= 'Normal' == option.inputValue;
			var action		= (isNormal) ? 'enable' : 'disable';
			fontAlignmentGroup.items.each(function(item) {
				item.ownerCt[action]();
				item[action]();
				if (!item.items) {
					return;
				}
				item.items.each(function(subitem) {
					subitem[action]();
				});
			});
			this.colorDecorationsGroup.layout.setActiveItem(select.items.indexOf(option));
			this.activeLinkState = option.inputValue;
		}, this);
		stateGroup.add(stateRadioGroup);
		this.menuItemsTab.add(stateGroup);

		// Create content group
		var contentGroup = new Sb.form.FieldGroup({
			columnWidth		: .75,
			autoWidth		: false
		});

		// Create content group -> font/alignment group
		var fontAlignmentGroup = new Sb.form.FieldGroup({
			cls				: 'clearfix'
		});
		this.fontFamilySizeGroup = new Sb.form.FontFamilySizePanel({
			fontFamilyWidth	: mediumCellWidth,
			fontSizeWidth	: smallCellWidth,
			widgetControlCls: widgetControlCls
		});
		fontAlignmentGroup.add(this.fontFamilySizeGroup);

		// Create content group -> font/alignment group -> alignment group
		this.alignmentGroup = new Sb.form.FieldGroup({
			itemId			: 'Alignment',
			layout			: 'column',
			itemCls			: widgetControlCls + 'alignment',
			fieldLabel		: SbGetLocaleByKey('widgetNavigationMenuAlignment')
		});
		Ext.each(this.alignments, function(alignment) {
			var alignmentButton = new Ext.Button({
				itemId		: alignment,
				iconCls		: 'x-edit-alignment-' + alignment.toLowerCase(),
				enableToggle: true
			});
			alignmentButton.on('toggle', function(button, pressed) {
				if (!pressed) {
					return;
				}
				this.alignmentGroup.items.each(function(button2) {
					if (!button2.pressed) {
						return;
					}
					if (button2.id == button.id) {
						return;
					}
					button2.toggle(false);
				});
			}, this);
			this.alignmentGroup.add(alignmentButton);
		}, this);
		fontAlignmentGroup.add(this.alignmentGroup);
		contentGroup.add(fontAlignmentGroup);

		// Create content group -> color/decorations group
		this.colorDecorationsGroup = new Sb.form.FieldGroup({
			layout				: 'card'
		});
		Ext.each(this.linkStates, function(linkState) {
			var panel = new Sb.form.ColorDecorationPanel({
				itemId			: linkState,
				cls				: widgetControlCls + 'color-decorations clearfix',
				colorComboWidth	: colorComboWidth,
				widgetControlCls	: widgetControlCls
			});
			if ('Normal' == linkState) {
				panel.toggle('BackgroundColor');
			}
			this.colorDecorationsGroup.add(panel);
		}, this);
		contentGroup.add(this.colorDecorationsGroup);

		this.menuItemsTab.add(contentGroup);

		this.on('show', this.bindMenuItemsTab, this);
		this.menuItemsTab.on('afterrender', this.bindMenuItemsTab, this, {single: true});
		fontAlignmentGroup.toggle('Alignment', false);
		this.menuItemsTab.on('activate', function () {
			var isShowAlignment = !(this.widget.el.up('#column1') || this.widget.el.up('#column2'));
			fontAlignmentGroup.toggle('Alignment', isShowAlignment);
			stateRadioGroup.setValue(this.linkStates[0]);
		}, this);
	},

	bindMenuItemsTab: function() {
		var model			= this.widget.model,
			palette			= Sb.Editor.model.design.palette,
			region			= this.widget.ownerCt.model.data.region;

		// Font family
		var fontFamily		= this.fontFamilySizeGroup.getComponent('FontFamily');
		var fontFamilyFn	= function() {
			model.setByLevel('FontFamily', this.value);
		};
		fontFamily.setValue(model.getByLevel('FontFamily'));
		fontFamily.on('select', fontFamilyFn);
		this.on('hide', function () {
			fontFamily.un('select', fontFamilyFn);
		}, null, {single: true});

		// Font size
		var fontSize		= this.fontFamilySizeGroup.getComponent('FontSize');
		var fontSizeFn		= function() {
			model.setByLevel('FontSize', this.getRawValue());
		};
		fontSize.setValue(model.getByLevel('FontSize'));
		fontSize.on('valid', fontSizeFn);
		this.on('hide', function () {
			fontSize.un('valid', fontSizeFn);
		}, null, {single: true});

		// Alignment
		var alignmentValue	= model.getByLevel('Alignment');
		Ext.each(this.alignments, function(alignmentType) {
			var alignmentBtn	= this.alignmentGroup.getComponent(alignmentType);
			if (alignmentType == alignmentValue) {
				alignmentBtn.toggle(true);
			}
			var alignmentFn		= function() {
				model.setByLevel('Alignment', this.itemId);
			};
			alignmentBtn.on('toggle', alignmentFn);
			this.on('hide', function () {
				alignmentBtn.un('toggle', alignmentFn);
			}, null, {single: true});
		}, this);

		// Link state -> Colors & Decorations
		Ext.each(this.linkStates, function(linkState) {
			// Local vars
			var stateForModel	= ('Normal' == linkState) ? '' : linkState;
			var colorTypes		= ['Color', 'BackgroundColor'];
			var panel			= this.colorDecorationsGroup.getComponent(linkState);

			// Colors
			Ext.each(colorTypes, function(colorType) {
				var modelKey		= colorType + stateForModel,
					paletteKey		= region + 'NavigationLevel1' + modelKey,
					colorCmb		= panel.getComponent(colorType),
					colorFn			= function() {
					model.setByLevel(modelKey, this.getValue());
					if ('BackgroundColor' == modelKey) {
						model.setByLevel('Container' + modelKey, this.getValue());
					}
				};

				colorCmb.setInitialValue(model.getByLevel(modelKey));
				colorCmb.setAutoValue(palette[paletteKey]);
				colorCmb.on('change', colorFn);
				this.on('hide', function () {
					colorCmb.un('change', colorFn);
				}, null, {single: true});
			}, this);

			// Decorations
			Ext.each(panel.decorations, function(decoration) {
				var modelKey		= decoration + stateForModel;
				var decorationBtn	= panel.getComponent('Decoration').getComponent(decoration);
				var decorationFn	= function() {
					model.setByLevel(modelKey, this.pressed);
				};
				decorationBtn.toggle(1 == model.getByLevel(modelKey));
				decorationBtn.on('toggle', decorationFn);
				this.on('hide', function () {
					decorationBtn.un('toggle', decorationFn);
				}, null, {single: true});
			}, this);
		}, this);
	},

	afterRender: function() {
		Sb.widget.NavigationEditPanel.superclass.afterRender.call(this);

		this.tabs.ft.first().first().createChild({
			cls: 'sb-widget-helper',
			cn: {
				cls: 'sb-widget-helper-wrap',
				cn: {
					cls: 'sb-widget-helper-inner',
					cn: {
						cls: 'sb-widget-helper-body'
					}
				}
			}
		});
		this.tabs.ft.child('.sb-widget-helper:first').setVisibilityMode(Ext.Element.DISPLAY);
	},

	/**
	 * Toggles display of helper message
	 * @param {Boolean} isShow
	 */
	toggleHelperMessage: function(isShow) {
		this.tabs.ft.child('.sb-widget-helper:first')[isShow ? 'show' : 'hide']();
	},

	/**
	 * Sets helper message for tab
	 * @param {String} message
	 */
	setHelperMessage: function(message) {
		this.tabs.ft.child('.sb-widget-helper-body:first').update(message);
		this.reanchor();
	},

	show: function(widget) {
		Sb.widget.NavigationEditPanel.superclass.show.call(this, widget);
		var data		= this.widget.model.data,
			value		= data.level + '-' + data.depth,
			selectBox	= Ext.getCmp('navigation-level'),
			store		= selectBox.store,
			record		= store.getAt(store.find('value', value));
		selectBox.setValue(value);
		this.setHelperMessage(record.get('message'));
	}
});