/**
 * @class Sb.widget.Script
 * @extends Sb.widget.Widget
 * Class for global Script widget
 * @xtype script_widget
 *
 * :INFO: "code" property in model is not exist for new widgets
 */
Sb.widget.Script = Ext.extend(Sb.widget.Widget, {
	cls: 'sb-widget-script',

	hasEditMenu: false,

	onRender: function() {
		Sb.widget.Script.superclass.onRender.apply(this, arguments);
		this.togglePlaceholder(true);
		this.renderPlaceholder();
	},

	initEvents: function () {
		Sb.widget.Script.superclass.initEvents.call(this);

		this.model.on('save', function () {
			Sb.Editor.Ui.mainWindow.statusBar.setMessage(
				SbGetLocaleByKey('messageChangesSaved')
			);
		});
	},

	/**
	 * Is widget has content, that could be rendered? Used in renderPlaceholder, for instance.
	 *
	 * @returns {Boolean}
	 */
	isEmpty: function() {
		return this.model.data.code ? false : true;
	},

	/**
	 * Render content for widget`s placeholder if it has one
	 * @return {Sb.widget.Widget} self
	 */
	renderPlaceholder: function() {
		var isEmpty			= this.isEmpty(),
			type			= this.model.data.type,
			stateMsgPart	= isEmpty ? 'Inactive' : 'Active',
			placeholderMsg	= SbGetLocaleByKey(type + 'Widget' + stateMsgPart + 'Text'),
			statusContent	= this.placeholderTpl.apply({placeholderMsg: placeholderMsg});

		Sb.widget.Script.superclass.renderPlaceholder.apply(this, arguments);
		this[isEmpty ? 'addClass' : 'removeClass'](this.getStateCls('inactive'));
		this.update(statusContent);
		return this;
	},

	onCompleteEdit: function() {
		this.model.unserialize({'code': this.getType().getEditPanel().codeTextArea.getValue()});
		this.model.saveIfChanged(this.memento);
	},

	onHideEdit: function() {
		Sb.widget.Script.superclass.onHideEdit.call(this);

		this.renderPlaceholder();
	}
});

Ext.reg('script_widget', Sb.widget.Script);