/**
 * @class Sb.widget.Search
 * @extends Sb.widget.Script
 * Class for search widget
 * @xtype search_widget
 */
Sb.widget.Search = Ext.extend(Sb.widget.Script, {
	/**
	 * @cfg {Sb.model.SearchWidget} model
	 * The {@link Sb.model.SearchWidget} to bind this Widget to.
	 */

	cls			: 'sb-widget-search',
	hasEditMenu	: false,

	isGoogle: function() {
		return 'Google' == this.model.data.provider;
	},

	isOther: function() {
		return 'Other' == this.model.data.provider;
	},

	onRender: function() {
		Sb.widget.Search.superclass.onRender.apply(this, arguments);
		this.refresh();
	},

	/**
	 * Render content for widget`s placeholder if it has one
	 * @return {Sb.widget.Widget} self
	 */
	renderPlaceholder: function() {
		Sb.widget.Search.superclass.renderPlaceholder.apply(this, arguments);
		this.togglePlaceholder(true);
		return this;
	},

	refresh: function() {
		this.update('');
		switch (true) {
		case this.isGoogle():
			this.refreshGoogle();
			break;
		case this.isOther():
			this.refreshOther();
			break;
		}
	},

	showGoogleSearchResults: function(isVisible) {
		Ext.fly('content-content-inner').addClass(this.getType().activeResultsClassName);
	},

	hideGoogleSearchResults: function() {
		Ext.fly('content-content-inner').removeClass(this.getType().activeResultsClassName);
	},

	refreshGoogle: function() {
		var resultsId	= 'sb-search-results-container';
		if (!Ext.getDom(resultsId)) {
			Ext.fly('content-content-inner').createChild({id: resultsId, 'class': 'widget-search-results'});
		}

		this.update('');
		this.togglePlaceholder(false);

		var resultsEl	= Ext.getDom(resultsId),
			searcher	= new google.search.WebSearch(),
			control		= new google.search.SearchControl(),
			options		= new google.search.SearcherOptions(),
			restriction	= Sb.Editor.model.data.publishWebSiteUrl || 'www.' + Sb.Utils.generateUuid() + '.com',
			noResults	= SbGetLocaleByKey(Sb.Editor.model.data.isPublished ? 'searchWidgetNoResults' : 'searchWidgetNoResultsAsNotPublished');

		searcher.setSiteRestriction(restriction);
		options.setRoot(resultsEl);
		options.setExpandMode(google.search.SearchControl.EXPAND_MODE_OPEN);
		control.addSearcher(searcher, options);
		control.setResultSetSize(google.search.Search.LARGE_RESULTSET);
		control.setNoResultsString(noResults);
		control.setSearchCompleteCallback(this, function(searchControl, searcher) {
			this.showGoogleSearchResults();
		});

		control.draw(this.widgetContentEl.id);
	},

	refreshOther: function() {
		this.hideGoogleSearchResults();
		this.renderPlaceholder();
	},

	initEvents: function() {
		Sb.widget.Search.superclass.initEvents.call(this);

		this.mon(this.model, 'providerchange', this.refresh, this);
		this.mon(this.model, 'save', this.onModelSave, this);
	},

	onModelSave: function() {
		Sb.Editor.Ui.mainWindow.statusBar.setMessage(
			SbGetLocaleByKey('messageChangesSaved')
		);
	},

	onDocumentClick: function(event) {
		if (event.getTarget('.' + this.getType().activeResultsClassName)) {
			return;
		}

		Sb.widget.Search.superclass.onDocumentClick.call(this, event);
	},

	onHideEdit: function() {
		Sb.widget.Search.superclass.onHideEdit.call(this);

		this.hideGoogleSearchResults();
		this.refresh();
	}

});

Ext.reg('search_widget', Sb.widget.Search);