Sb.widget.SearchEditPanel = Ext.extend(Sb.widget.ScriptEditPanel, {

	initComponent: function() {
		Ext.apply(this, {
			cls			: 'sb-widget-edit-panel-script sb-widget-edit-panel-search'
		});

		Sb.widget.SearchEditPanel.superclass.initComponent.apply(this, arguments);

		this.items.clear();
		this.items.add(this.widgetLabel);
		this.items.add(this.createInsertTypeGroup());
	},

	/**
	 * Fills up select options array once
	 */
	fillSelectOptions: function() {
		var selectOptions		= ['Google', 'Other'];
		Ext.each(selectOptions, function (selectOption, index) {
			var selectOption = new Ext.form.Radio({
				boxLabel		: SbGetLocaleByKey('searchWidgetSelectOption' + selectOption),
				inputValue		: selectOption,
				name			: 'selectOptions',
				itemCls			: 'sb-search-provider-' + selectOption.toLowerCase()
			});
			selectOption.on('render', function() {
				selectOption.wrap.unselectable();
			}, selectOption, {single: true});
			selectOptions[index] = selectOption;
		});

		return selectOptions;
	},

	/**
	 * Generate insert type selection group
	 *
	 * @return {Ext.Container}
	 */
	createInsertTypeGroup: function() {

		/**
		 * Select radio group
		 *
		 * @type Ext.form.RadioGroup
		 */
		this.selectRadioGroup = new Ext.form.RadioGroup({
			items			: this.fillSelectOptions(),
			columns			: 1,
			itemCls			: 'sb-widget-edit-panel-script-radio-group'
		});

		var selectGroup		= new Sb.form.FieldGroup({
				items		: this.selectRadioGroup
			}),
			optionsGroup	= new Sb.form.FieldGroup(),
			insertTypeGroup	= new Ext.Container({
				layout		: 'form',
				items		: [selectGroup, optionsGroup]
			});

		/**
		 * Insert type panels
		 *
		 * @type Ext.Panel
		 */
		this.insertTypePanels = new Ext.Panel({
			layout		: 'card',
			items		: [this.createGooglePanel(), this.createOtherPanel()]
		});
		optionsGroup.add(this.insertTypePanels);

		this.selectRadioGroup.on('change', function (select, option) {
			this.insertTypePanels.layout.setActiveItem(select.items.indexOf(option));
			this.widget.model.setProperty('provider', option.inputValue);
			this.reanchor();
		}, this);

		this.on('show', function () {
			this.selectRadioGroup.setValue(this.widget.model.data.provider);
		}, this);

		return insertTypeGroup;
	},

	/**
	 * Generate google tab
	 *
	 * @return {Ext.Panel}
	 */
	createGooglePanel: function() {
		/**
		 * Google tab
		 *
		 * @type Sb.form.FieldGroup
		 */
		this.googlePanel = new Sb.form.FieldGroup({
			layout		: 'form',
			cls			: 'sb-widget-search-google-panel',
			labelAlign	: 'top'
		});
		this.googlePanel.on('render', this.renderGooglePanel, this, {single: true});
		return this.googlePanel;
	},

	/**
	 * Render google tab
	 */
	renderGooglePanel: function() {},

	/**
	 * Generate other tab
	 *
	 * @return {Ext.Panel}
	 */
	createOtherPanel: function() {
		/**
		 * Other tab
		 *
		 * @type Ext.Panel
		 */
		this.otherPanel = new Sb.form.FieldGroup({
			layout		: 'form',
			labelAlign	: 'top',
			cls			: 'sb-widget-edit-panel-script-form'
		});
		this.otherPanel.on('render', this.renderOtherPanel, this, {single: true});
		return this.otherPanel;
	},

	/**
	 * Render other tab
	 */
	renderOtherPanel: function() {

		this.codeTextArea.on('render', function() {
			this.el.set({
				spellcheck: false
			});
		});

		this.codeTextArea.on('valid', this.otherUpdateCodeProperty, this);

		this.otherPanel.add(this.codeTextArea);
	},

	/**
	 * Updates model property from form field
	 */
	otherUpdateCodeProperty: function() {
		this.widget.model.setProperty('code', this.codeTextArea.getValue());
	}

});