/**
 * Base class for all widget edit panels
 *
 * @class Sb.widget.WidgetEditPanel
 * @extends Sb.editor.component.BaseEditPanel
 */
Sb.widget.WidgetEditPanel = Ext.extend(Sb.editor.component.BaseEditPanel, {
	show: function(widget) {
		this.widget = widget;
		Sb.widget.WidgetEditPanel.superclass.show.call(this, widget);
	},

	/**
	 * Binds fields of the panel to model, unversally integrating change events.
	 *
	 * @param {Array|Object} fieldsMapping Mapping of fields to model. Could be just array or object modelKey => fieldName.
	 */
	bindModel: function(fieldsMapping) {
		var model	= this.widget.model,
			data	= model.data,
			fields	= {};

		if (Ext.isString(fieldsMapping)) {
			fieldsMapping = [fieldsMapping];
		}
		if (Ext.isArray(fieldsMapping)) {
			Ext.each(fieldsMapping, function(item) {
				fields[item] = item;
			});
		} else {
			fields	= fieldsMapping;
		}

		Ext.iterate(fields, function(modelKey, fieldName) {
			var	fieldObj	= this[fieldName],
				fieldXType	= fieldObj.getXType(),
				eventName	= 'valid',
				getValueFn	= 'getRawValue',
				setValueFn	= 'setValue',
				changeFn	= function() {
					model.setProperty(modelKey, this[getValueFn]());
				};

			if ('checkbox' == fieldXType) {
				eventName	= 'check';
				getValueFn	= 'getValue';
			} else if ('button' == fieldXType) {
				if (!fieldObj.enableToggle) {
					return;
				}
				eventName	= 'toggle';
				getValueFn	= 'getPressed';
				setValueFn	= 'toggle';
			} else if ('colordropdown' == fieldXType) {
				eventName	= 'change';
				getValueFn	= 'getValue';
				setValueFn	= 'setInitialValue';
			}
			fieldObj[setValueFn](data[modelKey]);
			if ('colordropdown' == fieldXType) {
				fieldObj.setAutoValue(null);
			}
			fieldObj.on(eventName, changeFn);
			this.on('hide', function () {
				fieldObj.un(eventName, changeFn);
			}, this, {single: true});
		}, this);
	}
});