<?php
require_once dirname(__FILE__) . '/../../includes/init.php';
require_once 'InlineResolver.php';

/**
 * Authentication module
 *
 * @author Alexander Ustimenko <austimenko@parallels.com>
 * @since 2010/11/14
 * @package SB
 * @subpackage Auth
 * @copyright (c) 2004-2010, Parallels
 */
class Module_ProtectedPage_Authentication {

	/**
	 * Auth settings
	 * @var array
	 */
	private $_settings;

	/**
	 * Messages
	 * @var array
	 */
	private $_messages;

	/**
	 * @param array $settings Settings with keys: username, password, realm, accessDenied
	 */
	function __construct($settings) {
		$this->_settings = $settings;
		$this->_messages = $this->_settings['messages'];

		$this->defaultAction();
	}

	/**
	 * Detects preview mode of Parallels Panels
	 *
	 * @param Zend_Controller_Request_Http $request
	 * @return boolean
	 */
	private function _isShowPreviewMessage(Zend_Controller_Request_Http $request) {
		if (!$this->_messages['previewDetected']) {
			return false;
		}

		$remoteIp = $request->getServer('REMOTE_ADDR');

		return (
			$remoteIp == $request->getServer('SERVER_ADDR') ||
			$remoteIp == $request->getServer('LOCAL_ADDR') ||
			$remoteIp == gethostbyname($request->getServer('SERVER_NAME'))
		);
	}

	function defaultAction() {
		$request			= new Zend_Controller_Request_Http();
		if ($this->_isShowPreviewMessage($request)) {
			die('<h1>' . $this->_messages['previewDetected'] . '</h1>');
		}

		$response			= new Zend_Controller_Response_Http();
		$authAdapter		= new Zend_Auth_Adapter_Http(array(
			'accept_schemes'	=> 'digest',
			'realm'				=> $this->_settings['realm'],
			'digest_domains'	=> '/',
			'nonce_timeout'		=> 3600,
		));

		$authAdapter
			->setRequest($request)
			->setResponse($response)
			->setDigestResolver(new Module_ProtectedPage_InlineResolver($this->_settings, 'digest'));

		$authResult = $authAdapter->authenticate();
		$response->sendHeaders();

		if (!$authResult->isValid()) {
			die('<h1>' . $this->_messages['accessDenied'] . '</h1>');
		}
	}

}